import Vue from "vue";
import VueRouter from "vue-router";

if (process.env.NODE_ENV === "development") {
    Vue.use(VueRouter);
}

import {ROUTER_MODE} from "../config/app";

import Home from "../views/home/index.vue";
import Empty from "../views/home/Empty.vue";

// 管理组相关
import authAdmin from "../views/userManage/admin/authAdmin.vue";
import authRole from "../views/userManage/admin/authRole.vue";
import authPermissionRule from "../views/userManage/admin/authPermissionRule.vue";
import systemParamConfig from "../views/userManage/param/systemParamConfig.vue";
import systemPDFTemplate from "../views/userManage/param/systemPDFTemplate";
import systemPDFModule from "../views/userManage/param/systemPDFModule";
import thirdSysApi from "../views/userManage/param/ThirdSysApiUpload.vue";
import thirdSysApiDownload from "../views/userManage/param/ThirdSysApiDownload.vue";
import showText from "../views/other/showText";

//基础数据维护
import invWarehouse from "../views/basic/invWarehouse"
import BussinessType from "../views/basic/BussinessType.vue";
import BussinessTypeLocl from "../views/basic/BussinessTypeLocl.vue";
import bussinessTypeThird from "../views/basic/BussinessTypeThird.vue";
import basicUnitMaintain from "../views/basic/CorpMaintain.vue";
import corpImport from "../views/basic/CorpImport.vue";
import corpExport from "../views/basic/CorpExport.vue";
import company from "../views/userManage/param/company.vue";
import thirdSys from "../views/basic/BasicThirdSys.vue"
import UdiInfoManage from "../views/basic/UdiInfoManage.vue";
import udiinfoExport from "../views/basic/UdiinfoExport.vue";
import UdiInfoImport from "../views/basic/UdiInfoImport.vue";
import udiInfoDb from "../views/basic/UdiInfoDb.vue";
import UdidbImportLog from "../views/basic/UdidbImportLog.vue";

import UdiInfoSmpUpload from "../views/smp/UdiInfoSmpUpload.vue";
// import ErpOrderSmpUpload from "../views/smp/ErpOrderSmpUpload.vue";

//出入库管理
import inout from "../views/inout/IOFinishOrder.vue";
import checkError from "../views/inout/IOCheckErrorOrder.vue";
import checkWait from "../views/inout/IOCheckWaitOrder.vue";
import additionalOrder from "@/views/inout/IOAdditionalOrder";

import code from "../views/inout/IOFinishCode.vue";
import errorCode from "../views/inout/IONewCode.vue";
import errorOrder from "../views/inout/IONewOrder.vue";
import ioErrorOrder from "../views/inout/IOErrorOrder.vue";
import waitOrder from "../views/inout/IOWaitOrder.vue";
import repeatOrder from "../views/inout/IORepeatOrder.vue";
import erpOrder from "../views/inout/IOErpOrder.vue";

import stockOrderSearch from "../views/business/stockOrderSearch";
import stockOrderNew from "../views/business/stockOrderNew";
import stockOrderWaitCheck from "../views/business/stockOrderWaitCheck";
import stockOrderEditor from "../views/business/stockOrderEditor";

//库存管理
import stockCheck from "../views/inventory/stockCheck.vue";
import onHand from "../views/inventory/OnHand.vue";
import inCodeLog from "../views/inventory/InCodeLog.vue";
import stockPrint from "../views/inventory/IncodeSearch.vue";
import inCodePrint from "../views/inventory/IncodePrint.vue";
import stockCode from "../views/inventory/stockCode.vue";
import stockOrderDelSearch from "../views/business/stockOrderDelSearch";

//库存
import invProducts from "../views/inventory/InvProducts.vue";
import udiTrace from "../views/inventory/UdiCodeTrace.vue";
import invUdiTraceOrder from "@/views/inventory/invUdiTraceOrder";

//第三方数据管理
import thrProducts from "../views/thrsys/ThrProducts.vue";
import thrProductsImport from "../views/thrsys/ThrProductsImport.vue";
import thrProductsExport from "../views/thrsys/ThrProductsExport.vue";
import ThrInvProducts from "../views/thrsys/ThrInvProducts.vue";
import thrInvProductsExport from "../views/thrsys/ThrInvProductsExport.vue";
import thrInvProductsImport from "../views/thrsys/ThrInvProductsImport.vue";
import ThrOrders from "../views/thrsys/ThrOrder.vue";
import thrOrderExport from "../views/thrsys/ThrOrderExport.vue";
import thrOrderImport from "../views/thrsys/ThrOrderImport.vue";
import ThrCorps from "../views/thrsys/ThrCorps.vue";
import thrCorpsExport from "../views/thrsys/ThrCorpsExport.vue";
import thrCorpsImport from "../views/thrsys/ThrCorpsImport.vue";

//供应商管理
import corpExportSmp from "../views/basic/CorpExportSmp.vue";
import udiinfoExportSmp from "../views/basic/UdiinfoExportSmp.vue";
import UdiInfoDonwloadSmp from "../views/basic/UdiInfoDonwloadSmp.vue";
import thrOrderExportSmp from "../views/thrsys/ThrOrderExportSmp.vue";
import thrProductsExportSmp from "../views/thrsys/ThrProductsExportSmp.vue";
// Vue.use(VueRouter);

const err401 = r =>
    require.ensure([], () => r(require("../views/error/err401.vue")), "home");
const err404 = r =>
    require.ensure([], () => r(require("../views/error/err404.vue")), "home");
const login = r =>
    require.ensure([], () => r(require("../views/login/index.vue")), "home");
const main = r =>
    require.ensure([], () => r(require("../views/home/main.vue")), "home");

// 注意 权限字段 authRule （严格区分大小写）
export const constantRouterMap = [
    {
        path: "*",
        component: err404,
        hidden: true
    },
    {
        path: "/401",
        component: err401,
        name: "401",
        hidden: true
    },
    {
        path: "/404",
        component: err404,
        name: "404",
        hidden: true
    },
    {
        path: "/500",
        component: err404,
        name: "500",
        hidden: true
    },

    {
        path: "/login",
        component: login,
        name: "登录",
        hidden: true
    },
    {
        path: "/",
        icon: "shouye",
        component: Home,
        redirect: "main",
        name: "首页",
        hidden: true,
        noDropdown: true,
        children: [
            {
                path: "main",
                component: main,
                name: "首页"
            }
        ]
    }
];

export default new VueRouter({
    // mode: 'history', //后端支持可开
    mode: ROUTER_MODE,
    routes: constantRouterMap,
    strict: process.env.NODE_ENV !== "production"
});

export const asyncRouterMap = [
    {
        path: "/userManage",
        redirect: "/userManage/authAdmin",
        component: Home,
        icon: "guanliyuan1",
        name: "系统管理",
        hidden: false,
        meta: {
            authRule: ["user_manage"]
        },

        // noDropdown: true,
        children: [
            {
                path: "authAdmin",
                component: authAdmin,
                name: "用户管理",
                icon: "",
                meta: {
                    authRule: ["admin/auth_admin"]
                }
            },
            {
                path: "authRole",
                component: authRole,
                name: "角色管理",
                icon: "",
                meta: {
                    authRule: ["admin/auth_role"]
                }
            },
            {
                path: "authPermissionRule",
                component: authPermissionRule,
                name: "权限管理",
                icon: "",
                meta: {
                    authRule: ["admin/auth_permission_rule"]
                }
            },
            {
                path: "/systemParam",
                component: Empty,
                name: "系统参数",
                redirect: "/systemParam/systemParamConfig",
                icon: "",
                meta: {
                    authRule: ["systemParam/systemParamConfig"]
                },
                children: [
                    {
                        path: "systemParamConfig",
                        component: systemParamConfig,
                        name: "运行参数",
                        icon: "",
                        meta: {
                            authRule: ["system/systemParamConfig"]
                        },
                    },
                    {
                        path: "bussinessType",
                        name: "扫码单据类型",
                        component: BussinessType,
                        meta: {
                            authRule: ["system/bussinessType"]
                        }
                    },

                    {
                        path: "bussinessTypeLocl",
                        name: "业务单据类型",
                        component: BussinessTypeLocl,
                        meta: {
                            authRule: ["system/BussinessTypeLocl"]
                        }
                    },
                    {
                        path: "bussinessTypeThird",
                        name: "第三方单据类型",
                        component: bussinessTypeThird,
                        meta: {
                            authRule: ["system/bussinessTypeThird"]
                        }
                    },
                    {
                        path: "thirdSys",
                        name: "第三方系统",
                        component: thirdSys,
                        meta: {
                            authRule: ["system/thirdSys"]
                        }
                    },
                ]
            },


            {
                path: "/systemPDFTemplate",
                component: Empty,
                name: "打印模板",
                redirect: "/systemPDFTemplate/template",
                icon: "",
                meta: {
                    authRule: ["systemParam/systemParamConfig"]
                },
                children: [
                    {
                        path: "template",
                        component: systemPDFTemplate,
                        name: "模板管理",
                        icon: "",
                        meta: {
                            authRule: ["pdf/template"]
                        }
                    },
                    {
                        path: "module",
                        component: systemPDFModule,
                        name: "打印设置",
                        icon: "",
                        meta: {
                            authRule: ["pdf/module"]
                        }
                    },
                ]
            },

            // {
            //     path: "bussinessType",
            //     name: "单据类型",
            //     component: BussinessType,
            //     meta: {
            //         authRule: ["product/bussinessType"]
            //     }
            // },
        ]
    },
    {
        path: "/inout",
        component: Home,
        redirect: "/inout/inoutOrder",
        icon: "tongyong",
        name: "单据管理",
        noDropdown: false,
        meta: {
            authRule: ["inout"]
        },
        children: [

            // {
            //     path: "ioErrorOrder",
            //     component: ioErrorOrder,
            //     name: "异常单据管理",
            //
            //     meta: {
            //         authRule: ["inout/ioErrorOrder"]
            //     }
            // },


            {
                path: "/inoutOrder",
                component: Empty,
                name: "扫码单据管理",
                redirect: "/inoutOrder/errorOrder",
                icon: "",
                meta: {
                    authRule: ["inout/inoutOrder"]
                },
                children: [
                    {
                        path: "errorOrder",
                        component: errorOrder,
                        name: "新增单据管理",
                        meta: {
                            authRule: ["inout/newOrder"]
                        }
                    },
                    {
                        path: "checkWait",
                        name: "等待校验单据",
                        component: checkWait,
                        meta: {
                            authRule: ["inout/checkWait"]
                        }
                    },
                    {
                        path: "main",
                        name: "扫码单据查询",
                        component: inout,
                        meta: {
                            authRule: ["inout/main"]
                        }
                    },

                    {
                        path: "checkError",
                        name: "校验异常单据",
                        component: checkError,
                        meta: {
                            authRule: ["inout/checkError"]
                        }
                    },

                    {
                        path: "erpOrder",
                        name: "ERP单据管理",
                        component: erpOrder,
                        hidden: true,
                        meta: {
                            authRule: ["inout/erpOrder"]
                        }
                    },
                    {
                        path: "detail",
                        name: "单号详情",
                        component: code,
                        hidden: true
                    },
                    {
                        path: "errorDetail",
                        name: "错误单号详情",
                        component: errorCode,
                        hidden: true
                    },

                    {
                        path: "repeatOrder",
                        component: repeatOrder,
                        name: "扫码订单号重复",
                        hidden: true,
                        meta: {
                            authRule: ["inout/repeatOrder"]
                        }
                    },

                ]
            },
            {
                path: "/busOrder",
                component: Empty,
                name: "业务单据管理",
                redirect: "/busOrder/stockOrderNew",
                meta: {
                    authRule: ["inout/busOrder"]
                },
                children: [
                    {
                        path: "stockOrderNew",
                        component: stockOrderNew,
                        name: "新增业务单据",
                        meta: {
                            authRule: ["stock/stockOrderNew"]
                        }
                    },
                    {
                        path: "stockOrderEditor",
                        component: stockOrderEditor,
                        name: "单据配货管理",
                        meta: {
                            authRule: ["stock/stockOrderEditor"]
                        }
                    },
                    {
                        path: "stockOrderWaitCheck",
                        component: stockOrderWaitCheck,
                        name: "待校验业务单据",
                        meta: {
                            authRule: ["stock/stockOrderWaitCheck"]
                        }
                    },
                    {
                        path: "stockOrderSearch",
                        component: stockOrderSearch,
                        name: "业务单据查询",
                        meta: {
                            authRule: ["stock/stockOrderSearch"]
                        }
                    },
                ]
            },
            {
                path: "stockOrderSearch",
                component: stockOrderSearch,
                name: "未核对单据",
                meta: {
                    authRule: ["stock/unCheck"]
                }
            },
            {
                path: "stockOrderDelSearch",
                component: stockOrderDelSearch,
                name: "已核对单据",
                meta: {
                    authRule: ["stock/Checked"]
                }
            },


        ]
    },
    {
        path: "/warehouse",
        redirect: "/warehouse/product",
        component: Home,
        icon: "tongyong",
        name: "库存管理",
        hidden: true,
        noDropdown: false,
        meta: {
            authRule: ["warehouse"]
        },
        children: [
            {
                path: "onHand",
                name: "现存量查询",
                component: onHand,
                hidden: true,
                meta: {
                    authRule: ["warehouse/onHand"]
                }
            },


            {
                path: "stockCode",
                name: "库存明细",
                component: stockCode,
                hidden: true,
                meta: {
                    authRule: ["warehouse/stockCode"]
                }
            },

        ]
    },

    {
        path: "/product",
        redirect: "/udiinfo/udiinfomg",
        component: Home,
        icon: "tongyong",
        name: "基础数据",
        hidden: false,
        noDropdown: false,
        meta: {
            authRule: ["basic"]
        },
        children: [
            {
                path: "invWarehouse",
                component: invWarehouse,
                name: "仓库信息",
                icon: "",
                meta: {
                    authRule: ["basicProduct/invWarehouse"]
                }
            },
            {
                path: "/udiinfo",
                redirect: "/udiinfo/udiinfomg",
                name: "医疗器械信息",
                component: Empty,
                meta: {
                    authRule: ["basic/products"]
                },
                children: [
                    {
                        path: "udiinfomg",
                        name: "医疗器械信息维护",
                        component: UdiInfoManage,
                        meta: {
                            authRule: ["basic/products/modify"]
                        }
                    },
                    {
                        path: "udiImport",
                        name: "医疗器械信息导入",
                        component: UdiInfoImport,
                        meta: {
                            authRule: ["basic/products/import"]
                        }
                    },
                    {
                        path: "udiinfoExport",
                        name: "医疗器械信息导出",
                        component: udiinfoExport,
                        meta: {
                            authRule: ["basic/products/export"]
                        }
                    },]
            },
            {
                path: "/unit",
                redirect: "/unit/unitMaintain",
                name: "往来单位信息",
                component: Empty,
                meta: {
                    authRule: ["basic/unit"]
                },
                children: [
                    {
                        path: "unitMaintain",
                        name: "往来单位信息维护",
                        component: basicUnitMaintain,
                        meta: {
                            authRule: ["basic/unit/maintain"]
                        }
                    },
                    {
                        path: "corpImport",
                        name: "往来单位信息导入",
                        component: corpImport,
                        meta: {
                            authRule: ["basic/corp/Import"]
                        }
                    },

                    {
                        path: "corpExport",
                        name: "往来单位信息导出",
                        component: corpExport,
                        meta: {
                            authRule: ["basic/corp/Export"]
                        }
                    },]
            },

            {
                path: "company",
                name: "本机构信息",
                component: company,
                meta: {
                    authRule: ["product/company"]
                }
            },

            {
                path: "/udidb",
                redirect: "/udidb/udidbSearch",
                name: "本地UDI库",
                component: Empty,
                meta: {
                    authRule: ["basic/udidb"]
                },
                children: [
                    {
                        path: "udidbSearch",
                        name: "DI信息查询",
                        component: udiInfoDb,
                        meta: {
                            authRule: ["basic/udidb/search"]
                        }
                    },
                    {
                        path: "UdidbImportLog",
                        name: "DI导入记录",
                        component: UdidbImportLog,
                        meta: {
                            authRule: ["basic/udidb/importLog"]
                        }
                    }
                ]
            },

        ]
    },
    {
        path: "/thrsys",
        redirect: "/products/thrProducts",
        component: Home,
        icon: "tongyong",
        name: "第三方数据",
        hidden: false,
        noDropdown: false,
        meta: {
            authRule: ["thrsys"]
        },
        children: [
            {
                path: "/products",
                redirect: "/products/thrProducts",
                name: "产品信息",
                component: Empty,
                meta: {
                    authRule: ["thrsys/thrProducts"]
                },
                children: [
                    {
                        path: "thrProducts",
                        name: "产品信息查询",
                        component: thrProducts,
                        meta: {
                            authRule: ["thrsys/thrProducts/search"]
                        },
                    },
                    {
                        path: "thrProductsImport",
                        name: "产品信息导入",
                        component: thrProductsImport,
                        meta: {
                            authRule: ["thrsys/thrProductsImport"]
                        }
                    },
                    {
                        path: "thrProductsExport",
                        name: "产品信息导出",
                        component: thrProductsExport,
                        meta: {
                            authRule: ["thrsys/thrProductsExport"]
                        }
                    },
                ]
            },
            {
                path: "/corps",
                redirect: "/corps/ThrCorps",
                name: "往来单位",
                component: Empty,
                meta: {
                    authRule: ["thrsys/corp"]
                },
                children: [
                    {
                        path: "ThrCorps",
                        name: "往来单位查询",
                        component: ThrCorps,
                        meta: {
                            authRule: ["thrsys/ThrCorps"]
                        }
                    },

                    {
                        path: "thrCorpsImport",
                        name: "往来单位导入",
                        component: thrCorpsImport,
                        meta: {
                            authRule: ["thrsys/thrCorpsImport"]
                        }
                    },
                    {
                        path: "thrCorpsExport",
                        name: "往来单位导出",
                        component: thrCorpsExport,
                        meta: {
                            authRule: ["thrsys/thrCorpsExport"]
                        }
                    }
                ],
            },
            {
                path: "/orders",
                redirect: "/orders/ThrOrders",
                name: "业务单据",
                component: Empty,
                meta: {
                    authRule: ["thrsys/throrders"]
                },
                children: [
                    {
                        path: "ThrOrders",
                        name: "业务单据查询",
                        component: ThrOrders,
                        meta: {
                            authRule: ["thrsys/order/search"]
                        }
                    },
                    {
                        path: "thrOrderImport",
                        name: "业务单据导入",
                        component: thrOrderImport,
                        meta: {
                            authRule: ["thrsys/thrOrderImport"]
                        }
                    },
                    {
                        path: "thrOrderExport",
                        name: "业务单据导出",
                        component: thrOrderExport,
                        meta: {
                            authRule: ["thrsys/thrOrderExport"]
                        }
                    },],
            },
            {
                path: "/invProducts",
                redirect: "/invProducts/ThrInvProducts",
                name: "库存信息",
                component: Empty,
                meta: {
                    authRule: ["thrsys/inv"]
                },
                children: [

                    {
                        path: "ThrInvProducts",
                        name: "库存信息查询",
                        component: ThrInvProducts,
                        meta: {
                            authRule: ["thrsys/ThrInvProducts"]
                        }
                    },
                    {
                        path: "thrInvProductsImport",
                        name: "库存信息导入",
                        component: thrInvProductsImport,
                        meta: {
                            authRule: ["thrsys/thrInvProductsImport"]
                        }
                    },
                    {
                        path: "thrInvProductsExport",
                        name: "库存信息导出",
                        component: thrInvProductsExport,
                        meta: {
                            authRule: ["thrsys/thrInvProductsExport"]
                        }
                    },]
            },

            // {
            //     path: "thirdSys",
            //     name: "参数设置",
            //     component: thirdSys,
            //     meta: {
            //         authRule: ["thrsys/thirdSys"]
            //     }
            // },

        ]
    },
    {
        path: "/smp",
        redirect: "/smp/udiinfoExportSmp",
        component: Home,
        icon: "tongyong",
        name: "供应商平台",
        hidden: false,
        noDropdown: false,
        meta: {
            authRule: ["smp"]
        },
        children: [
            {
                path: "udiinfoExportSmp",
                name: "器械信息上传",
                component: udiinfoExportSmp,

                meta: {
                    authRule: ["thrsys/udiinfoExportSmp"]
                }
            },
            {
                path: "UdiInfoDonwloadSmp",
                name: "器械信息下载",
                component: UdiInfoDonwloadSmp,

                meta: {
                    authRule: ["thrsys/UdiInfoDonwloadSmp"]
                }
            },
            {
                path: "corpExportSmp",
                name: "往来单位上传",
                component: corpExportSmp,
                meta: {
                    authRule: ["thrsys/corpExportSmp"]
                }
            },
            {
                path: "thrProductsExportSmp",
                name: "第三方产品信息上传",
                component: thrProductsExportSmp,
                meta: {
                    authRule: ["thrsys/thrProductsExportSmp"]
                }
            },
            {
                path: "thrOrderExportSmp",
                name: "第三方业务单据上传",
                component: thrOrderExportSmp,
                meta: {
                    authRule: ["thrsys/thrOrderExportSmp"]
                }
            },
            {
                path: "orderSmpDl",
                name: "送货单下载",
                component: UdiInfoSmpUpload,
                hidden: true,
                meta: {
                    authRule: ["thrsys/UdiInfoSmpUpload"]
                }
            },

        ]
    },
    {
        path: "/myCode",
        redirect: "/myCode/inCodeLog",
        component: Home,
        icon: "tongyong",
        name: "内部码管理",
        hidden: false,
        noDropdown: false,
        meta: {
            authRule: ["myCode"]
        },
        children: [

            {
                path: "inCodeLog",
                name: "内部码生成",
                component: inCodeLog,
                meta: {
                    authRule: ["warehouse/inCodeLog"]
                }
            },
            {
                path: "inCodePrint",
                name: "内部码打印",
                component: inCodePrint,
                meta: {
                    authRule: ["warehouse/inCodePrint"]
                }
            },
            {
                path: "stockPrint",
                name: "内部码查询",
                component: stockPrint,

                meta: {
                    authRule: ["warehouse/stockPrint"]
                }
            },
        ]
    },
    {
        path: "/inv",
        redirect: "/inv/invProducts",
        component: Home,
        icon: "tongyong",
        name: "库存管理",
        hidden: false,
        noDropdown: false,
        meta: {
            authRule: ["inv/manage"]
        },
        children: [
            {
                path: "additionalOrder",
                component: additionalOrder,
                name: "补录单据管理",
                meta: {
                    authRule: ["stock/additionalOrder"]
                }
            },
            {
                path: "invProducts",
                component: invProducts,
                name: "库存查询",
                icon: "",
                meta: {
                    authRule: ["inv/invProducts"]
                }
            },

            {
                path: "stockCheck",
                name: "盘点单据",
                component: stockCheck,
                meta: {
                    authRule: ["inv/stockCheck"]
                }
            },
            {
                path: "udiTrace",
                name: "UDI码追溯查询",
                component: invUdiTraceOrder,
                meta: {
                    authRule: ["inv/udiTrace"]
                }
            },
        ]
    },
    {
        path: "/api",
        redirect: "/api/thirdSysApi",
        component: Home,
        icon: "tongyong",
        name: "API接口",
        hidden: false,
        noDropdown: false,
        meta: {
            authRule: ["api"]
        },
        children: [
            {
                path: "thirdSysApi",
                name: "基础信息上传",
                component: thirdSysApi,

                meta: {
                    authRule: ["api/thirdSysApi"]
                }
            },
            {
                path: "thirdSysApiDownload",
                name: "基础信息下载",
                component: thirdSysApiDownload,

                meta: {
                    authRule: ["api/thirdSysApiDownload"]
                }
            },


        ]
    },
    {
        path: "/",
        icon: "showText",
        component: showText,
        redirect: "showText",
        name: "文本",
        hidden: true,
        noDropdown: true,
        children: [
            {
                path: "showText",
                component: showText,
                name: "文本",
            },
        ]
    },
];
